# `resotodata`
Public Resoto Cloud Data

Location data is open data, licensed under the [Open Data Commons Open Database License (ODbL)](https://opendatacommons.org/licenses/odbl/) by the [OpenStreetMap Foundation (OSMF)](https://wiki.osmfoundation.org/wiki/Main_Page).

Carbon Emissions data is open source, licensed under the [Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0) by [Cloud Carbon Footprint](https://www.cloudcarbonfootprint.org/).

EC2 Instances Info is open source, licensed under the [MIT License](https://opensource.org/licenses/MIT) by [EC2Instances.info](https://ec2instances.info/).
